/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.ranger.security.context;

import java.io.Serializable;

public class RangerAdminOpContext implements Serializable {
	private static final long serialVersionUID = 1L;
	private boolean bulkModeContext = false;
	private Boolean createPrincipalsIfAbsent = null;

	public boolean isBulkModeContext() {
		return bulkModeContext;
	}

	public void setBulkModeContext(boolean bulkMode) {
		this.bulkModeContext = bulkMode;
	}

	public Boolean getCreatePrincipalsIfAbsent() {
		return createPrincipalsIfAbsent;
	}

	public void setCreatePrincipalsIfAbsent(Boolean createPrincipalsIfAbsent) {
		this.createPrincipalsIfAbsent = createPrincipalsIfAbsent;
	}
}
